@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_INCIDENCEDEFAULTS_H
@@ -23,11 +10,13 @@
 
 #include "incidenceeditor_export.h"
 
-#include <KCalCore/Incidence>
+#include <KCalendarCore/Incidence>
 
 namespace IncidenceEditorNG {
 class IncidenceDefaultsPrivate;
-
+/**
+ * @brief The IncidenceDefaults class
+ */
 class INCIDENCEEDITOR_EXPORT IncidenceDefaults
 {
 public:
@@ -40,10 +29,7 @@ public:
     /**
       Sets the attachments that are added by default to incidences.
     */
-    void setAttachments(const QStringList &attachments,
-                        const QStringList &attachmentMimetypes = QStringList(),
-                        const QStringList &attachmentLabels = QStringList(),
-                        bool inlineAttachment = false);
+    void setAttachments(const QStringList &attachments, const QStringList &attachmentMimetypes = QStringList(), const QStringList &attachmentLabels = QStringList(), bool inlineAttachment = false);
 
     /**
       Sets the attendees that are added by default to incidences.
@@ -63,7 +49,7 @@ public:
 
     /**
       This is used to do a smarter guess about which identity to use for the organizer.
-      If the groupware server is not set, the first avaialble identity will be used.
+      If the groupware server is not set, the first available identity will be used.
       @param domain The gropuware server domain name without any protocol prefixes
       (e.g. demo.kolab.org).
     */
@@ -73,7 +59,7 @@ public:
       Sets the incidence related to the incidence for which to set the defaults. For
       example the parent todo of a new sub todo.
     */
-    void setRelatedIncidence(const KCalCore::Incidence::Ptr &incidence);
+    void setRelatedIncidence(const KCalendarCore::Incidence::Ptr &incidence);
 
     /**
       Set the start date/time to use for passed incidences. This defaults to the
@@ -93,11 +79,11 @@ public:
 
     /**
       Sets the default values for @param incidence. This method is merely meant for
-      <em>new</em> icidences. However, it will clear out all fields and set them
+      <em>new</em> incidences. However, it will clear out all fields and set them
       to default values.
       @param incidence The incidence that will get default values for all of its field.
     */
-    void setDefaults(const KCalCore::Incidence::Ptr &incidence) const;
+    void setDefaults(const KCalendarCore::Incidence::Ptr &incidence) const;
 
     /**
      * Returns minimal incidence defaults: e-mails and groupware domain.
@@ -105,11 +91,11 @@ public:
      * TODO: See if this is always called when using IncidenceDefaults.
      * If yes, this should be done inside ctor.
      */
-    static IncidenceDefaults minimalIncidenceDefaults(bool cleanupAttachmentTempFiles = false);
+    Q_REQUIRED_RESULT static IncidenceDefaults minimalIncidenceDefaults(bool cleanupAttachmentTempFiles = false);
 
     // Returns the e-mail address used for the organizer when we can't find anything useful
     // This is something like "invalid@invalid"
-    static QString invalidEmailAddress();
+    Q_REQUIRED_RESULT static QString invalidEmailAddress();
 
 private:
     IncidenceDefaultsPrivate *const d_ptr;
